@@ -92,12 +92,10 @@ ConfigQml::set_iconset(QString c)
     saveConfig();
     refreshconfig();
 }
+
 QString
 ConfigQml::iconspath(){
-    QString c;
-    c = ConfigQml::Config::prefix_path().c_str();
-    c.append("/icons");
-    return c;
+    return ConfigQml::Config::iconspath().c_str(); 
 }
 
 QString
@@ -141,7 +139,9 @@ ConfigQml::windspeedunit(){
     c = QString(QString::fromUtf8(_(ConfigQml::Config::WindSpeedUnit().c_str())));
     return c;
 }
-QStringList ConfigQml::windspeed_list()
+
+QStringList 
+ConfigQml::windspeed_list()
 {
     QStringList l;
     for (int i=0; i < wind_list.size(); i++){
@@ -149,12 +149,28 @@ QStringList ConfigQml::windspeed_list()
     }
     return l;
 }
-void ConfigQml::windspeed_unit(int index)
+
+void 
+ConfigQml::windspeed_unit(int index)
 {
     ConfigQml::Config::WindSpeedUnit(wind_list.at(index).toStdString());
     saveConfig();
     refreshconfig();
 }
+
+bool
+ConfigQml::fullscreen()
+{
+    return ConfigQml::Config::Fullscreen();
+}
+void
+ConfigQml::setfullscreen(bool c)
+{
+    ConfigQml::Config::Fullscreen(c);
+    saveConfig();
+    refreshconfig();
+}
+
 QString
 ConfigQml::version(){
     QString c;
@@ -316,16 +332,21 @@ ConfigQml::saveStation1(QString city_id, QString city_name, QString region, QStr
     Core::SourceList *sourcelist = new Core::SourceList(path);
 
     std::string url_template = sourcelist->at(source_id)->url_template();
+    std::string url_for_view = sourcelist->at(source_id)->url_for_view();
 
     char forecast_url[4096];
     snprintf(forecast_url, sizeof(forecast_url)-1, url_template.c_str(), code.c_str());
+    char view_url[4096];
+    snprintf(view_url, sizeof(view_url)-1, url_for_view.c_str(), code.c_str());
+
     station = new Core::Station(
                 source.toStdString(),
                 code,
                 city_name.toStdString(),
                 country.toStdString(),
                 region.toStdString(),
-                forecast_url);
+                forecast_url,
+                view_url);
     std::string filename(Core::AbstractConfig::getConfigPath());
     filename += source.toStdString();
     filename += "_";
@@ -357,16 +378,21 @@ ConfigQml::saveStation(int city_id, QString city,
     Core::SourceList *sourcelist = new Core::SourceList(path);
 
     std::string url_template = sourcelist->at(source_id)->url_template();
+    std::string url_for_view = sourcelist->at(source_id)->url_for_view();
 
     char forecast_url[4096];
     snprintf(forecast_url, sizeof(forecast_url)-1, url_template.c_str(), code.c_str());
+    char view_url[4096];
+    snprintf(view_url, sizeof(forecast_url)-1, url_for_view.c_str(), code.c_str());
+
     station = new Core::Station(
                 source.toStdString(),
                 code,
                 city.toStdString(),
                 country.toStdString(),
                 region.toStdString(),
-                forecast_url);
+                forecast_url,
+                view_url);
     std::string filename(Core::AbstractConfig::getConfigPath());
     filename += source.toStdString();
     filename += "_";
@@ -380,40 +406,25 @@ ConfigQml::saveStation(int city_id, QString city,
     refreshconfig();
 
 }
+
 QString
 ConfigQml::stationname()
 {
-    if (this->current_station_id() == INT_MAX && this->stationsList().size() > 0){
-        this->current_station_id(0);
-    }
-    if (this->current_station_id() != INT_MAX && this->stationsList().size() > 0
-        &&  this->stationsList().at(this->current_station_id()))
-        return this->stationsList().at(this->current_station_id())->name().c_str();
-    else
-        return "Unknown";
+    return ConfigQml::Config::stationname().c_str();
 }
+
 QString
 ConfigQml::nextstationname()
 {
-    if (this->current_station_id() != INT_MAX && this->stationsList().size() > 0
-        && (this->current_station_id() + 1) < this->stationsList().size()
-        &&  this->stationsList().at(this->current_station_id()+1)){
-        return this->stationsList().at(this->current_station_id()+1)->name().c_str();
-    }else {
-        return "";
-    }
+    return ConfigQml::Config::nextstationname().c_str(); 
 }
+
 QString
 ConfigQml::prevstationname()
 {
-    if (this->current_station_id() != INT_MAX && this->stationsList().size() > 0
-        && (this->current_station_id() - 1) >= 0
-        &&  this->stationsList().at(this->current_station_id()-1)){
-        return this->stationsList().at(this->current_station_id()-1)->name().c_str();
-    }else {
-        return "";
-    }
+    return ConfigQml::Config::prevstationname().c_str(); 
 }
+
 QString
 ConfigQml::filename()
 {
@@ -423,6 +434,7 @@ ConfigQml::filename()
     else
         return QString();
 }
+
 QString
 ConfigQml::source()
 {
@@ -432,6 +444,17 @@ ConfigQml::source()
     else
         return QString();
 }
+
+QString
+ConfigQml::viewURL()
+{
+    if (this->current_station_id() != INT_MAX && this->stationsList().size() > 0
+                                                &&  this->stationsList().at(this->current_station_id()))
+        return this->stationsList().at(this->current_station_id())->viewURL().c_str();
+    else
+        return QString();
+}
+
 void
 ConfigQml::changestation()
 {
@@ -441,8 +464,9 @@ ConfigQml::changestation()
    }else {
        this->current_station_id(0);
    }
-
+   this->saveConfig();
 }
+
 void
 ConfigQml::nextstation()
 {
@@ -452,8 +476,9 @@ ConfigQml::nextstation()
    }else {
        this->current_station_id(0);
    }
-
+   this->saveConfig();
 }
+
 void
 ConfigQml::prevstation()
 {
@@ -463,7 +488,7 @@ ConfigQml::prevstation()
    }else {
        this->current_station_id(stationsList().size());
    }
-
+   this->saveConfig();
 }
 void
 ConfigQml::refreshconfig(){
@@ -483,6 +508,15 @@ ConfigQml::updatestations()
     thread->start();
 
 }
+
+void
+ConfigQml::showweb()
+{
+    if (this->current_station_id() != INT_MAX && this->stationsList().size() > 0
+                                                &&  this->stationsList().at(this->current_station_id()))
+        QDesktopServices::openUrl(QUrl(this->stationsList().at(this->current_station_id())->viewURL().c_str()));     
+}
+
 void
 ConfigQml::downloadFinishedSlot()
 {
